Class AssociateEntityToThingRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.iotthingsgraph.model.IoTThingsGraphRequest
software.amazon.awssdk.services.iotthingsgraph.model.AssociateEntityToThingRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<AssociateEntityToThingRequest.Builder,AssociateEntityToThingRequest>
@Generated("software.amazon.awssdk:codegen")
public final class AssociateEntityToThingRequest
extends IoTThingsGraphRequest
implements ToCopyableBuilder<AssociateEntityToThingRequest.Builder,AssociateEntityToThingRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final StringentityId()The ID of the device to be associated with the thing.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final LongThe version of the user's namespace.static Class<? extends AssociateEntityToThingRequest.Builder>final StringThe name of the thing to which the entity is to be associated.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
thingName
The name of the thing to which the entity is to be associated.
- Returns:
- The name of the thing to which the entity is to be associated.
-
entityId
The ID of the device to be associated with the thing.
The ID should be in the following format.
urn:tdm:REGION/ACCOUNT ID/default:device:DEVICENAME- Returns:
- The ID of the device to be associated with the thing.
The ID should be in the following format.
urn:tdm:REGION/ACCOUNT ID/default:device:DEVICENAME
-
namespaceVersion
The version of the user's namespace. Defaults to the latest version of the user's namespace.
- Returns:
- The version of the user's namespace. Defaults to the latest version of the user's namespace.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AssociateEntityToThingRequest.Builder,AssociateEntityToThingRequest> - Specified by:
toBuilderin classIoTThingsGraphRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-